@@ -1,6 +1,6 @@
 /*
  *  Queue load balancing system
- *  $Revision: 1.2 $
+ *  $Revision: 1.3 $
  *
  *  Copyright (C) 1998 Werner G. Krebs
  *
@@ -742,10 +742,18 @@ mkutmp("root",pty2,uid,gid);
 #endif
 
 tcflush(pty2,TCIOFLUSH);
-if(tcsetattr(pty2,0,&globalterm)<0) {
-  syslog(LOG_ERR,"tcsetattr: %m");
+#ifdef TCSANOW
+/*IRIX requires TCSANOW to be present.*/
+if(tcsetattr(pty2,TCSANOW,&globalterm)<0) {
+  syslog(LOG_ERR,"tcsetattr on fd %d: %m",pty2);
   exit(2);
 }
+#else
+if(tcsetattr(pty2,0,&globalterm)<0) {
+  syslog(LOG_ERR,"tcsetattr on fd %d: %m",pty2);
+  exit(2);
+}
+#endif /*TCSANOW*/
 #ifdef TIOCSWINSZ
        if(ioctl (pty2, TIOCSWINSZ, (char *)&ws) <0) {
 	 syslog(LOG_ERR,"ioctl TIOCSWINSZ: %m");
