@@ -1,6 +1,6 @@
 /*
  *  Queue load balancing system
- *  $Revision: 1.2 $
+ *  $Revision: 1.3 $
  *  Copyright (C) 1998 Werner G. Krebs
  *
  *  werner.krebs@yale.edu
@@ -33,6 +33,8 @@
 char *mtos();
 char buf2[1000];
 
+char *line = NULL;
+
 struct utmp myu;
 
 extern int compar(const void *one, const void *two);
@@ -52,6 +54,16 @@ FILE *queue;
 struct dirent *temp;
 char *file, c;
 
+#ifdef HAVE__GETPTY
+
+/*IRIX*/
+
+   line = _getpty(&fd, O_RDWR|O_NDELAY, 0600, 0);
+
+if(line) return(fd);
+
+#else
+
 dirnum = 0;
 #ifdef __hpux
 dir = opendir("/dev/ptym");
@@ -100,6 +112,7 @@ if((fd = open(buf2,O_RDWR))<0) {
 
 return(fd);
 }
+#endif /*HAVE__GETPTY*/
 syslog(LOG_ERR,"ptyalloc: no more ptys");
 return(-1);
 }
@@ -149,6 +162,15 @@ char *mtos()
 char *ptym;
 static char buf[16];
 register int i;
+
+#ifdef HAVE__GETPTY
+if(line) return(line);
+
+syslog(LOG_ERR,"mtos: call allocpty first.");
+return(NULL);
+
+#else
+
 ptym = buf2;
 for(i=0;ptym[i]!=0;++i) if(ptym[i]=='/') {
   ptym = &ptym[i+1];
@@ -164,4 +186,5 @@ sprintf(buf,"/dev/t%s",ptym+1);
 #endif
 
 return(buf);
+#endif /*HAVE__GETPTY*/
 }
