@@ -29,6 +29,10 @@ in queued.c*/
   currently around 255.*/
 #endif
 
+#ifndef MAXHOSTNAMELEN
+#define MAXHOSTNAMELEN 64
+#endif
+
 struct wkstruct{
 char *host;
 float load;
@@ -78,9 +82,6 @@ typedef int fdev; /*should normally be OK.*/
 #endif
 
 #ifndef SYS_SIGLIST_DECLARED 
-#ifndef __hpux
-extern char	*sys_siglist[NSIG];
-#else
 static char	*sys_siglist[NSIG] = {
 	"Signal 0",
 	"Hangup",			/* SIGHUP */
@@ -117,7 +118,6 @@ static char	*sys_siglist[NSIG] = {
 	"Signal 31"
 #endif
 };
-#endif /*__hpux*/
 #endif /*SYS_SIGLIST_DECLARED*/
 
 
@@ -190,8 +190,7 @@ typedef char bat_Mail;
 
 #ifndef sigmask
 #define sigmask(sig) \
-  (((unsigned long) 1) << (((sig) - 1) % (8 * sizeof (unsigned long
-int))))
+  (((unsigned long) 1) << (((sig) - 1) % (8 * sizeof (unsigned long int))))
 #endif /*sigmask*/
 
 #ifndef HAVE_HERROR
@@ -202,6 +201,20 @@ that this work.*/
 #endif /*HAVE_HERROR*/
 /*WGK End SUN-OS stuff.*/
 
+/*WGK 1999/01/24 FreeBSD stuff*/
+     /*These constants are Or'd in, so if the platform
+doesn't support them, set them to zero.*/
+
+#ifndef XCASE
+#define XCASE   0
+#endif /* XCASE*/
+
+#ifndef IUCLC
+#define IUCLC 0
+#endif /*IUCLC*/
+
+/*WGK End FreeBSD stuff*/
+
 #endif /*_QUEUE*/
 
 
