@@ -1,6 +1,6 @@
 /*
  *  Queue load balancing system
- *  $Revision: 1.1.1.6 $
+ *  $Revision: 1.2 $
  *
  *  Copyright (C) 1998 Werner G. Krebs
  *  
@@ -71,20 +71,21 @@ hello.sin_family = myhost->h_addrtype;
 
 /* We try to connect five times to prevent an overloaded system from
 keeping us down.*/
+ again:
 if((w_fd = socket(AF_INET,SOCK_STREAM,0))<0) {
   perror("socket");
   exit(2);
 }
- again:
  status = connect(w_fd,(const void*) &hello,sizeof(hello));
  if(status <0) {
    if(count < 5) {
 /*     sleep(1);*/
      count++;
+        close(w_fd);
      goto again;
    }
    perror("con_daemon: connect");
-   fprintf(stderr,"Batchd down on %s?\n",hostname);
+   fprintf(stderr,"QueueD down on %s?\n",hostname);
    close(w_fd);
    return(0);
  }
@@ -123,13 +124,16 @@ if((w_fd = socket(AF_INET,SOCK_STREAM,0))<0) {
  again:
  status = connect(w_fd,(const void*) &hello,sizeof(hello));
  if(status <0) {
+#if 0
+   /* doesn't work, w_fd is in error state and cannot be reused anyway. */
    if(count < 1) {
      sleep(1);
      count++;
      goto again;
    }
+#endif
    perror("getrldavg: connect");
-   fprintf(stderr,"Batchd down on %s?\n",hostname);
+   fprintf(stderr,"QueueD down on %s?\n",hostname);
    close(w_fd);
    return(1e08);
  }
